summaryrefslogtreecommitdiffstats
path: root/tools/h5repack/h5repack.h
diff options
context:
space:
mode:
Diffstat (limited to 'tools/h5repack/h5repack.h')
-rw-r--r--tools/h5repack/h5repack.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/tools/h5repack/h5repack.h b/tools/h5repack/h5repack.h
index a397d0a..3fa23d3 100644
--- a/tools/h5repack/h5repack.h
+++ b/tools/h5repack/h5repack.h
@@ -153,6 +153,8 @@ int do_copy_refobjs(hid_t fidin,
void read_info(const char *filename,pack_opt_t *options);
void init_packobject(pack_info_t *obj);
int print_filters(hid_t dcpl_id);
+int have_request(pack_opt_t *options);
+
/*-------------------------------------------------------------------------
@@ -163,8 +165,9 @@ int print_filters(hid_t dcpl_id);
int apply_filters(const char* name, /* object name from traverse list */
int rank, /* rank of dataset */
hsize_t *dims, /* dimensions of dataset */
- hid_t dcpl_id, /* dataset creation property list */
- pack_opt_t *options); /* repack options */
+ hid_t dcpl_id, /* (IN,OUT) dataset creation property list */
+ pack_opt_t *options, /* repack options */
+ int *has_filter); /* (OUT) object NAME has a filter */
int has_filter(hid_t dcpl_id,
H5Z_filter_t filtnin);